==> haskell-text-builder-linear-0.1.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-linear
version:              0.1.3
visibility:           public
id:                   text-builder-linear-0.1.3-FMXdxH7WNkqDoB7SMMYtlk
key:                  text-builder-linear-0.1.3-FMXdxH7WNkqDoB7SMMYtlk
license:              BSD-3-Clause
copyright:            2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko
homepage:             https://github.com/Bodigrim/linear-builder
synopsis:             Builder for Text and ByteString based on linear types
description:
    Strict Text and ByteString builder, which hides mutable buffer behind linear types
    and takes amortized linear time.

category:             Text
abi:                  5d6df083baf8fc0ba5cf348e1f92adf4
exposed:              True
exposed-modules:
    Data.Text.Builder.Linear Data.Text.Builder.Linear.Buffer
    Data.Text.Builder.Linear.Core

hidden-modules:
    Data.Text.Builder.Linear.Array Data.Text.Builder.Linear.Char
    Data.Text.Builder.Linear.Dec.Bounded
    Data.Text.Builder.Linear.Dec.Unbounded
    Data.Text.Builder.Linear.Double Data.Text.Builder.Linear.Hex
    Data.Text.Builder.Linear.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-linear
hs-libraries:         HStext-builder-linear-0.1.3-FMXdxH7WNkqDoB7SMMYtlk
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-bignum-1.3
    quote-quot-0.2.1.0-CNtEIJqsYxLE2ohn8yPvnb text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-linear/html/text-builder-linear.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-linear-0.1.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-linear
version:              0.1.3
visibility:           public
id:                   text-builder-linear-0.1.3-1LMD0leN1Kv4EMhbAHeG8l
key:                  text-builder-linear-0.1.3-1LMD0leN1Kv4EMhbAHeG8l
license:              BSD-3-Clause
copyright:            2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko
homepage:             https://github.com/Bodigrim/linear-builder
synopsis:             Builder for Text and ByteString based on linear types
description:
    Strict Text and ByteString builder, which hides mutable buffer behind linear types
    and takes amortized linear time.

category:             Text
abi:                  3afdfe306c02302323b6621c69480686
exposed:              True
exposed-modules:
    Data.Text.Builder.Linear Data.Text.Builder.Linear.Buffer
    Data.Text.Builder.Linear.Core

hidden-modules:
    Data.Text.Builder.Linear.Array Data.Text.Builder.Linear.Char
    Data.Text.Builder.Linear.Dec.Bounded
    Data.Text.Builder.Linear.Dec.Unbounded
    Data.Text.Builder.Linear.Double Data.Text.Builder.Linear.Hex
    Data.Text.Builder.Linear.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-linear-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-linear
hs-libraries:         HStext-builder-linear-0.1.3-1LMD0leN1Kv4EMhbAHeG8l
depends:
    base-4.17.2.1 bytestring-0.11.5.3 ghc-bignum-1.3
    quote-quot-0.2.1.0-BjWKKn3ZjRuJ3YfghnaQYx text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-linear/html/text-builder-linear.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
